=== added file '.bzrignore'
--- .bzrignore	1970-01-01 00:00:00 +0000
+++ .bzrignore	2012-01-27 18:44:27 +0000
@@ -0,0 +1,2 @@
+.testrepository
+django_timeline.egg-info

=== added file '.testr.conf'
--- .testr.conf	1970-01-01 00:00:00 +0000
+++ .testr.conf	2012-01-27 18:44:27 +0000
@@ -0,0 +1,4 @@
+[DEFAULT]
+test_command=${PYTHON:-python} -m subunit.run $LISTOPT $IDOPTION timeline_django.tests.test_suite
+test_id_option=--load-list $IDFILE
+test_list_option=--list

=== added file 'README'
=== added file 'setup.py'
--- setup.py	1970-01-01 00:00:00 +0000
+++ setup.py	2012-01-27 18:44:27 +0000
@@ -0,0 +1,26 @@
+import os
+
+from setuptools import setup, find_packages
+
+setup(
+    name='django_timeline',
+    version='0.0.1',
+    packages=find_packages(),
+    include_package_data=True,
+    maintainer='Launchpad developers',
+    maintainer_email='launchpad-devs@lists.launchpad.net',
+    description='Insert Django database queries in to a Timeline',
+    long_description=open(os.path.join(os.path.dirname(__file__), 'README')).read(),
+    license='LGPLv3',
+    url='http://launchpad.net/python-django-timeline',
+    download_url='https://launchpad.net/python-django-timeline/+download',
+    test_suite='timeline_django.tests',
+    install_requires = [
+        'Django',
+        ],
+    tests_require = [
+        'timeline',
+        ],
+    # Auto-conversion to Python 3.
+    use_2to3=True,
+    )

=== added directory 'timeline_django'
=== added file 'timeline_django/__init__.py'
=== added file 'timeline_django/middleware.py'
--- timeline_django/middleware.py	1970-01-01 00:00:00 +0000
+++ timeline_django/middleware.py	2012-01-27 18:44:27 +0000
@@ -0,0 +1,34 @@
+import threading
+
+
+TIMELINE_VAR = 'timeline'
+
+
+_thread_local = threading.local()
+
+
+def get_timeline():
+    """Get the timeline associated with the current request, if any.
+
+    If `TimelineMiddleware` saved a `Timeline` object at the start of
+    the request calling this function will return it. If there isn't
+    a saved timeline then `None` will be returned.
+    """
+    return getattr(_thread_local, TIMELINE_VAR, None)
+
+
+class TimelineMiddleware(object):
+    """Save a `Timeline` as a thread local.
+
+    This middleware looks in `request.environ` for a `timeline.timeline`
+    key, and if it is present it stores it in a thread local variable,
+    so that `get_timeline` will return it when later called in that
+    thread.
+    """
+
+    TIMELINE_ENVIRON_KEY = 'timeline.timeline'
+
+    def process_request(self, request):
+        if self.TIMELINE_ENVIRON_KEY in request.environ:
+            setattr(_thread_local, TIMELINE_VAR,
+                    request.environ[self.TIMELINE_ENVIRON_KEY])

=== added directory 'timeline_django/tests'
=== added file 'timeline_django/tests/__init__.py'
--- timeline_django/tests/__init__.py	1970-01-01 00:00:00 +0000
+++ timeline_django/tests/__init__.py	2012-01-27 18:44:27 +0000
@@ -0,0 +1,9 @@
+import unittest
+
+def test_suite():
+    module_names = [
+        'timeline_django.tests.test_middleware',
+        ]
+    loader = unittest.TestLoader()
+    suite = loader.loadTestsFromNames(module_names)
+    return suite

=== added file 'timeline_django/tests/test_middleware.py'
--- timeline_django/tests/test_middleware.py	1970-01-01 00:00:00 +0000
+++ timeline_django/tests/test_middleware.py	2012-01-27 18:44:27 +0000
@@ -0,0 +1,35 @@
+import threading
+
+from testtools import TestCase
+from timeline import Timeline
+
+from .. import middleware
+
+
+class Request(object):
+
+    def __init__(self, environ):
+        self.environ = environ
+
+
+class TimelineMiddlewareTests(TestCase):
+
+    def setUp(self):
+        super(TimelineMiddlewareTests, self).setUp()
+        self.patch(middleware, '_thread_local', threading.local())
+
+    def test_get_timeline_is_None(self):
+        self.assertEqual(None, middleware.get_timeline())
+
+    def test_middleware_doesnt_set_timeline_if_not_in_environ(self):
+        mw = middleware.TimelineMiddleware()
+        request = Request({})
+        mw.process_request(request)
+        self.assertEqual(None, middleware.get_timeline())
+
+    def test_middleware_sets_timeline(self):
+        mw = middleware.TimelineMiddleware()
+        timeline = Timeline()
+        request = Request({'timeline.timeline': timeline})
+        mw.process_request(request)
+        self.assertEqual(timeline, middleware.get_timeline())

